==> daas-bm-core-1.0.0-sources.jar: in/clouthink/daas/bm/domain/rest/BusinessMessageSummary.java <==
package in.clouthink.daas.bm.domain.rest;

import in.clouthink.daas.bm.domain.model.BusinessMessage;
import org.springframework.beans.BeanUtils;

import java.util.Date;

/**
 */
public class BusinessMessageSummary {

	public static BusinessMessageSummary from(BusinessMessage from) {
		if (from == null) {
			return null;
		}
		BusinessMessageSummary result = new BusinessMessageSummary();
		convert(from, result);
		return result;
	}

	public static void convert(BusinessMessage from, BusinessMessageSummary result) {
		BeanUtils.copyProperties(from, result);
	}

	String id;

	String category;

	String title;

	String receiverId;

	String receiverType;

	String receiverName;

	String senderId;

	String senderType;

	String senderName;

	Date sendAt;

	boolean read;

	boolean processed;

	boolean deleted;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getCategory() {
		return category;
	}

	public void setCategory(String category) {
		this.category = category;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getReceiverId() {
		return receiverId;
	}

	public void setReceiverId(String receiverId) {
		this.receiverId = receiverId;
	}

	public String getReceiverType() {
		return receiverType;
	}

	public void setReceiverType(String receiverType) {
		this.receiverType = receiverType;
	}

	public String getReceiverName() {
		return receiverName;
	}

	public void setReceiverName(String receiverName) {
		this.receiverName = receiverName;
	}

	public String getSenderId() {
		return senderId;
	}

	public void setSenderId(String senderId) {
		this.senderId = senderId;
	}

	public String getSenderType() {
		return senderType;
	}

	public void setSenderType(String senderType) {
		this.senderType = senderType;
	}

	public String getSenderName() {
		return senderName;
	}

	public void setSenderName(String senderName) {
		this.senderName = senderName;
	}

	public Date getSendAt() {
		return sendAt;
	}

	public void setSendAt(Date sendAt) {
		this.sendAt = sendAt;
	}

	public boolean isRead() {
		return read;
	}

	public void setRead(boolean read) {
		this.read = read;
	}

	public boolean isProcessed() {
		return processed;
	}

	public void setProcessed(boolean processed) {
		this.processed = processed;
	}

	public boolean isDeleted() {
		return deleted;
	}

	public void setDeleted(boolean deleted) {
		this.deleted = deleted;
	}
}

==> daas-bm-core-1.0.2-sources.jar: in/clouthink/daas/bm/domain/rest/BusinessMessageSummary.java <==
package in.clouthink.daas.bm.domain.rest;

import in.clouthink.daas.bm.domain.model.BusinessMessage;
import org.springframework.beans.BeanUtils;

import java.util.Date;

/**
 * @author dz
 */
public class BusinessMessageSummary {

	public static BusinessMessageSummary from(BusinessMessage from) {
		if (from == null) {
			return null;
		}
		BusinessMessageSummary result = new BusinessMessageSummary();
		convert(from, result);
		return result;
	}

	public static void convert(BusinessMessage from, BusinessMessageSummary result) {
		BeanUtils.copyProperties(from, result);
	}

	private String id;

	private String category;

	private String title;

	private String receiverId;

	private String receiverType;

	private String receiverName;

	private String senderId;

	private String senderType;

	private String senderName;

	private Date sendAt;

	private boolean read;

	private boolean processRequired;

	private boolean processed;

	private boolean deleted;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getCategory() {
		return category;
	}

	public void setCategory(String category) {
		this.category = category;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getReceiverId() {
		return receiverId;
	}

	public void setReceiverId(String receiverId) {
		this.receiverId = receiverId;
	}

	public String getReceiverType() {
		return receiverType;
	}

	public void setReceiverType(String receiverType) {
		this.receiverType = receiverType;
	}

	public String getReceiverName() {
		return receiverName;
	}

	public void setReceiverName(String receiverName) {
		this.receiverName = receiverName;
	}

	public String getSenderId() {
		return senderId;
	}

	public void setSenderId(String senderId) {
		this.senderId = senderId;
	}

	public String getSenderType() {
		return senderType;
	}

	public void setSenderType(String senderType) {
		this.senderType = senderType;
	}

	public String getSenderName() {
		return senderName;
	}

	public void setSenderName(String senderName) {
		this.senderName = senderName;
	}

	public Date getSendAt() {
		return sendAt;
	}

	public void setSendAt(Date sendAt) {
		this.sendAt = sendAt;
	}

	public boolean isRead() {
		return read;
	}

	public void setRead(boolean read) {
		this.read = read;
	}

	public boolean isProcessRequired() {
		return processRequired;
	}

	public void setProcessRequired(boolean processRequired) {
		this.processRequired = processRequired;
	}

	public boolean isProcessed() {
		return processed;
	}

	public void setProcessed(boolean processed) {
		this.processed = processed;
	}

	public boolean isDeleted() {
		return deleted;
	}

	public void setDeleted(boolean deleted) {
		this.deleted = deleted;
	}
}
